@@ -20,4 +20,8 @@ paintPoints <- function(aDetectedPlot, aBasePlot, size = 8, color = "blue") {
                          thick = TRUE) 
   
   return(theNew)
+}
+
+unitTrim <- function(unit) {
+  as.numeric(sub("native", "", as.character(unit)))
 }
\ No newline at end of file
